-- 党员干部学习
DROP TABLE IF EXISTS `party_cadre_study`;
CREATE TABLE `party_cadre_study`
(
    id                        bigint       not null comment '主键编号'
        primary key,
    create_user_id            bigint       null comment '创建人',
    create_date               datetime     null comment '创建时间',
    modify_user_id            bigint       null comment '修改人',
    modify_date               datetime     null comment '修改时间',
    delete_mark               int          not null comment '删除标记',
    enabled_mark              int          not null comment '有效标志',
    sort_code                 int          null comment '序号',

    party_tissue_id           bigint       not null comment '党组织主键id(party_tissue_manager)',
    party_tissue_name         varchar(256) not null comment '党组织名称',
    party_tissue_code         varchar(256) not null comment '党组织编号',

    party_train_way_carrier   varchar(500) not null comment '党员干部学习培训主要途径和载体',
    party_train_way_content   varchar(500) not null comment '党员干部学习培训内容',

    start_time                date         not null comment '活动开始日期',
    end_time                  date         not null comment '活动结束日期',

    participate_teacher_count int          null comment '参与教师数',
    participate_student_count int          null comment '参与学生数'
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
    comment '党员干部学习';

-- 党员干部学习活动参与人
DROP TABLE IF EXISTS `party_cadre_study_participant`;
CREATE TABLE `party_cadre_study_participant`
(
    id                   bigint       not null comment '主键编号'
        primary key,
    create_user_id       bigint       null comment '创建人',
    create_date          datetime     null comment '创建时间',
    modify_user_id       bigint       null comment '修改人',
    modify_date          datetime     null comment '修改时间',
    delete_mark          int          not null comment '删除标记',
    enabled_mark         int          not null comment '有效标志',
    sort_code            int          null comment '序号',

    party_cadre_study_id bigint       null comment '党员干部学习主键id（party_cadre_study）',
    participant_id       bigint       null comment '活动参与人id',
    participant_remark   varchar(256) null comment '活动参与人类型',
    participant_username varchar(256) null comment '活动参与人oa',
    participant_user_id  varchar(256) null comment '活动参与人学号，工号',
    participant_name     varchar(256) null comment '活动参与人姓名'
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
    comment '党员干部学习活动参与人';

# 数据字典
# par_part 党员干部学习培训内容
# 值  名称               编号
# 1 党的理论              par_part1
# 2 相关政策文件            par_part2
# 3 党规党纪及国家法律法规   par_part3
# 4 教育教学业务            par_part4
# 5 学校管理              par_part5
# 6 文化建设              par_part6
# 7 经济方面              par_part7
# 8 互联网与新媒体方面     par_part8
# 9 心理健康              par_part9
# 10 师德师风             par_part10
# 99 其他                 par_part99
#
# party_way 党员干部学习培训主要途径和载体
# 值  名称               编号
# 1  实践活动             party_way1
# 2  会议               party_way2
# 3  讲座报告             party_way3
# 4  学校定期集中学习         party_way4
# 5  支部定期集中学习         party_way5
# 6   微信 QQ               party_way6
# 7  移动端培训平台          party_way7
# 8  分发图书资料           party_way8
# 9  个人学习             party_way9
# 10 在线教育网站           party_way10
# 11 参观学习             party_way11
# 99 其他                   party_way99

DROP TABLE IF EXISTS party_class_manage;
CREATE TABLE party_class_manage
(
    id                        bigint       not null comment '主键编号' primary key,
    create_user_id            bigint       null comment '创建人',
    create_date               datetime     null comment '创建时间',
    modify_user_id            bigint       null comment '修改人',
    modify_date               datetime     null comment '修改时间',
    delete_mark               int          not null comment '删除标记',
    enabled_mark              int          not null comment '有效标志',
    sort_code                 int          null comment '序号',

    party_tissue_name         varchar(256) not null comment '党组织名称',
    party_tissue_code         varchar(256) not null comment '党组织编号',
    party_tissue_id           bigint       not null comment '党组织主键id(party_tissue_manager)',

    activity_type             varchar(256) not null comment '活动形式',
    speaker_name              varchar(256) null comment '党课主讲人',

    start_time                date         not null comment '活动开始时间',
    end_time                  date         not null comment '活动结束时间',

    activities_content        text         NULL COMMENT '活动内容',

    participate_teacher_count int          null comment '参与教师数',
    participate_student_count int          null comment '参与学生数'

) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
    COMMENT ='党课管理数据表';


DROP TABLE IF EXISTS party_class_manage_participant;
CREATE TABLE party_class_manage_participant
(
    id                    bigint       not null comment '主键编号' primary key,
    create_user_id        bigint       null comment '创建人',
    create_date           datetime     null comment '创建时间',
    modify_user_id        bigint       null comment '修改人',
    modify_date           datetime     null comment '修改时间',
    delete_mark           int          not null comment '删除标记',
    enabled_mark          int          not null comment '有效标志',
    sort_code             int          null comment '序号',

    party_class_manage_id bigint       not null comment '党课管理id',

    participant_id        bigint       null comment '活动参与人id',
    participant_remark    varchar(256) null comment '活动参与人类型',
    participant_username  varchar(256) null comment '活动参与人oa',
    participant_user_id   varchar(256) null comment '活动参与人学号，工号',
    participant_name      varchar(256) null comment '活动参与人姓名'

) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
    COMMENT ='党课活动参与人表';

-- 党建活动
DROP TABLE IF EXISTS `party_build_event`;
CREATE TABLE party_build_event
(
    id                 bigint       not null comment '主键编号'
        primary key,
    create_user_id     bigint       null comment '创建人',
    create_date        datetime     null comment '创建时间',
    modify_user_id     bigint       null comment '修改人',
    modify_date        datetime     null comment '修改时间',
    delete_mark        int          not null comment '删除标记',
    enabled_mark       int          not null comment '有效标志',
    sort_code          int          null comment '序号',

    event_type         varchar(255) not null comment '活动类型',
    party_tissue_id    bigint       not null comment '党组织主键id(party_tissue_manager)',
    party_tissue_name  varchar(256) not null comment '党组织名称',
    party_tissue_code  varchar(256) not null comment '党组织编号',
    event_address      varchar(255) null comment '活动地点',
    event_content      text         null comment '活动内容',
    event_start_time   date         not null comment '活动开始时间',
    event_end_time     date         not null comment '活动结束时间',
    attend_teacher_num int          null comment '参于教师数',
    attend_student_num int          null comment '参于学生数'
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
    COMMENT ='党建活动';

-- 党建活动参与人员
DROP TABLE IF EXISTS `party_build_event_participant`;
CREATE TABLE `party_build_event_participant`
(
    id                   bigint       not null comment '主键编号'
        primary key,
    create_user_id       bigint       null comment '创建人',
    create_date          datetime     null comment '创建时间',
    modify_user_id       bigint       null comment '修改人',
    modify_date          datetime     null comment '修改时间',
    delete_mark          int          not null comment '删除标记',
    enabled_mark         int          not null comment '有效标志',
    sort_code            int          null comment '序号',

    party_build_event_id bigint       null comment '党建活动主键id（party_build_event）',
    participant_id       bigint       null comment '参与活动人id',
    participant_remark   varchar(256) null comment '活动参与人类型',
    participant_username varchar(256) null comment '活动参与人oa',
    participant_user_id  varchar(256) null comment '活动参与人学号，工号',
    participant_name     varchar(256) null comment '活动参与人姓名'
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
    comment '党建活动参与人员';


